@@ -749,6 +749,23 @@ final class t3lib_extMgm {
 		}
 	}
 
+	/**
+	 * Registers an Ext.Direct component with access restrictions.
+	 *
+	 * @param string $endpointName
+	 * @param string $callbackClass
+	 * @param string $moduleName optional: must be <mainmodule> or <mainmodule>_<submodule>
+	 * @param string $accessLevel optional: can be 'admin' or 'user,group'
+	 * @return void
+	 */
+	public static function registerExtDirectComponent($endpointName, $callbackClass, $moduleName = NULL, $accessLevel = NULL) {
+		$GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['ExtDirect'][$endpointName] = array(
+			'callbackClass' => $callbackClass,
+			'moduleName' => $moduleName,
+			'accessLevel' => $accessLevel,
+		);
+	}
+
 	/**
 	 * Adds a module path to TBE_MODULES for used with the module dispatcher, mod.php
 	 * Used only for modules that are not placed in the main/sub menu hierarchy by the traditional mechanism of addModule()
@@ -896,7 +913,6 @@ final class t3lib_extMgm {
 			// but maybe it's better to move non-available services to a different array??
 
 		if ($serviceType &&
-				!t3lib_div::hasValidClassPrefix($serviceType) &&
 				t3lib_div::hasValidClassPrefix($serviceKey, array('user_')) &&
 				is_array($info)) {
 
@@ -1393,14 +1409,15 @@ $_EXTCONF = $TYPO3_CONF_VARS[\'EXT\'][\'extConf\'][$_EXTKEY];
 	 * Returns true if both the localconf and tables cache file exists (with $cacheFilePrefix)
 	 * Usage: 2
 	 *
-	 * @param	string		Prefix of the cache file to check
-	 * @return	boolean
-	 * @internal
+	 * @param $cacheFilePrefix string Prefix of the cache file to check
+	 * @return boolean
 	 */
 	public static function isCacheFilesAvailable($cacheFilePrefix) {
 		return
-				@is_file(PATH_typo3conf . $cacheFilePrefix . '_ext_localconf.php') &&
-						@is_file(PATH_typo3conf . $cacheFilePrefix . '_ext_tables.php');
+			@is_file(PATH_typo3conf . $cacheFilePrefix . '_ext_localconf.php') &&
+				@is_file(PATH_typo3conf . $cacheFilePrefix . '_ext_tables.php') &&
+				@filesize(PATH_typo3conf . $cacheFilePrefix . '_ext_localconf.php') > 0 &&
+				@filesize(PATH_typo3conf . $cacheFilePrefix . '_ext_tables.php') > 0;
 	}
 
 	/**
