@@ -828,10 +828,10 @@ class t3lib_userAuth {
 
 		if ($statement && $user) {
 				// A user was found
-			if (is_string($this->auth_timeout_field)) {
-				$timeout = intval($user[$this->auth_timeout_field]); // Get timeout-time from usertable
-			} else {
+			if (t3lib_div::testInt($this->auth_timeout_field)) {
 				$timeout = intval($this->auth_timeout_field); // Get timeout from object
+			} else {
+				$timeout = intval($user[$this->auth_timeout_field]); // Get timeout-time from usertable
 			}
 				// If timeout > 0 (true) and currenttime has not exceeded the latest sessions-time plus the timeout in seconds then accept user
 				// Option later on: We could check that last update was at least x seconds ago in order not to update twice in a row if one script redirects to another...
@@ -1487,4 +1487,4 @@ if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLA
 	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_userauth.php']);
 }
 
-?>
\ No newline at end of file
+?>
