@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,9 +27,9 @@
 /**
  * Plugin 'Content rendering' for the 'css_styled_content' extension.
  *
- * $Id: class.tx_cssstyledcontent_pi1.php 7184 2010-03-26 16:02:00Z lolli $
+ * $Id$
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 /**
  * [CLASS/FUNCTION INDEX of SCRIPT]
@@ -56,7 +56,7 @@
  * Plugin class - instantiated from TypoScript.
  * Rendering some content elements from tt_content table.
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage tx_cssstyledcontent
  */
@@ -101,7 +101,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			if (!strcmp($content,''))	return '';
 
 				// Split into single lines:
-			$lines = t3lib_div::trimExplode(chr(10),$content);
+			$lines = t3lib_div::trimExplode(LF,$content);
 			foreach($lines as &$val)	{
 				$val = '<li>'.$this->cObj->stdWrap($val,$conf['innerStdWrap.']).'</li>';
 			}
@@ -173,7 +173,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			$headerIdPrefix = $headerScope.$this->cObj->data['uid'].'-';
 
 				// Split into single lines (will become table-rows):
-			$rows = t3lib_div::trimExplode(chr(10),$content);
+			$rows = t3lib_div::trimExplode(LF,$content);
 			reset($rows);
 
 				// Find number of columns to render:
@@ -314,7 +314,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			if (count($fileArray))	{
 
 					// Get the descriptions for the files (if any):
-				$descriptions = t3lib_div::trimExplode(chr(10),$this->cObj->data['imagecaption']);
+				$descriptions = t3lib_div::trimExplode(LF,$this->cObj->data['imagecaption']);
 
 					// Adding hardcoded TS to linkProc configuration:
 				$conf['linkProc.']['path.']['current'] = 1;
@@ -325,6 +325,9 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 				if ($conf['labelStdWrap.']) {
 					$conf['linkProc.']['labelStdWrap.'] = $conf['labelStdWrap.'];
 				}
+				if ($conf['useSpacesInLinkText'] || $conf['stripFileExtensionFromLinkText']) {
+					$conf['linkProc.']['removePrependedNumbers'] = 0;
+				}
 
 					// Traverse the files found:
 				$filesData = array();
@@ -347,7 +350,18 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 						$GLOBALS['TSFE']->register['fileSize'] = $filesData[$key]['filesize'];
 						$GLOBALS['TSFE']->register['fileExtension'] = $filesData[$key]['fileextension'];
 						$GLOBALS['TSFE']->register['description'] = $filesData[$key]['description'];
-						$filesData[$key]['linkedFilenameParts'] = explode('//**//',$this->cObj->filelink($fileName, $conf['linkProc.']));
+						$filesData[$key]['linkedFilenameParts']
+							= $this->beautifyFileLink(
+								explode(
+									'//**//',
+									$this->cObj->filelink(
+										$fileName, $conf['linkProc.']
+									)
+								),
+								$fileName,
+								$conf['useSpacesInLinkText'],
+								$conf['stripFileExtensionFromLinkText']
+							);
 					}
 				}
 
@@ -391,6 +405,77 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 		}
 	}
 
+	/**
+	 * returns an array containing width relations for $colCount columns.
+	 * 
+	 * tries to use "colRelations" setting given by TS.
+	 * uses "1:1" column relations by default. 
+	 *
+	 * @param array $conf TS configuration for img
+	 * @param int $colCount number of columns
+	 * @return array
+	 */
+	protected function getImgColumnRelations($conf, $colCount) {
+		$relations = array();
+		$equalRelations= array_fill(0, $colCount, 1);
+		$colRelationsTypoScript = trim($this->cObj->stdWrap($conf['colRelations'], $conf['colRelations.']));
+
+		if ($colRelationsTypoScript) {
+				// try to use column width relations given by TS
+			$relationParts = explode(':', $colRelationsTypoScript);
+				// enough columns defined?
+			if (count($relationParts) >= $colCount) {
+				$out = array();
+				for ($a = 0; $a < $colCount; $a++) {
+					$currentRelationValue = intval($relationParts[$a]);
+					if ($currentRelationValue >= 1) {
+						$out[$a] = $currentRelationValue;
+					} else {
+						t3lib_div::devLog('colRelations used with a value smaller than 1 therefore colRelations setting is ignored.', $this->extKey, 2);
+						unset($out);
+						break;
+					}
+				}
+				if (max($out) / min($out) <= 10) {
+					$relations = $out;
+				} else {
+					t3lib_div::devLog('The difference in size between the largest and smallest colRelation was not within a factor of ten therefore colRelations setting is ignored..', $this->extKey, 2);
+				}
+			}
+		}
+		return $relations ? $relations : $equalRelations;
+	}
+	
+	/**
+	 * returns an array containing the image widths for an image row with $colCount columns.
+	 *
+	 * @param array $conf TS configuration of img
+	 * @param int $colCount number of columns
+	 * @param int $netW max usable width for images (without spaces and borders)
+	 * @return array
+	 */
+	protected function getImgColumnWidths($conf, $colCount, $netW) {
+		$columnWidths = array();
+		$colRelations = $this->getImgColumnRelations($conf, $colCount);
+		
+		$accumWidth = 0;
+		$accumDesiredWidth = 0;
+		$relUnitCount = array_sum($colRelations);
+		
+		for ($a = 0; $a < $colCount; $a++)	{
+			$availableWidth = $netW - $accumWidth; // this much width is available for the remaining images in this row (int)
+			$desiredWidth = $netW / $relUnitCount * $colRelations[$a]; // theoretical width of resized image. (float)
+			$accumDesiredWidth += $desiredWidth; // add this width. $accumDesiredWidth becomes the desired horizontal position 
+				// calculate width by comparing actual and desired horizontal position.
+				// this evenly distributes rounding errors across all images in this row. 
+			$suggestedWidth = round($accumDesiredWidth - $accumWidth);
+			$finalImgWidth = (int) min($availableWidth, $suggestedWidth); // finalImgWidth may not exceed $availableWidth
+			$accumWidth += $finalImgWidth;
+			$columnWidths[$a] = $finalImgWidth;
+		}
+		return $columnWidths;
+	}
+	
 	/**
 	 * Rendering the IMGTEXT content element, called from TypoScript (tt_content.textpic.20)
 	 *
@@ -513,37 +598,12 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			}
 		}
 
-			// All columns have the same width:
-		$defaultColumnWidth = ceil(($maxW-$colspacing*($colCount-1)-$colCount*$border*($borderThickness+$borderSpace)*2)/$colCount);
+			// max usuable width for images (without spacers and borders)
+		$netW = $maxW - $colspacing * ($colCount - 1) - $colCount * $border * ($borderThickness + $borderSpace) * 2;
 
 			// Specify the maximum width for each column
-		$columnWidths = array();
-		$colRelations = trim($this->cObj->stdWrap($conf['colRelations'],$conf['colRelations.']));
-		if (!$colRelations)	{
-				// Default 1:1-proportion, all columns same width
-			for ($a=0;$a<$colCount;$a++)	{
-				$columnWidths[$a] = $defaultColumnWidth;
-			}
-		} else {
-				// We need another proportion
-			$rel_parts = explode(':',$colRelations);
-			$rel_total = 0;
-			for ($a=0;$a<$colCount;$a++)	{
-				$rel_parts[$a] = intval($rel_parts[$a]);
-				$rel_total+= $rel_parts[$a];
-			}
-			if ($rel_total)	{
-				for ($a=0;$a<$colCount;$a++)	{
-					$columnWidths[$a] = round(($defaultColumnWidth*$colCount)/$rel_total*$rel_parts[$a]);
-				}
-				if (min($columnWidths)<=0 || max($rel_parts)/min($rel_parts)>10)	{
-					// The difference in size between the largest and smalles must be within a factor of ten.
-					for ($a=0;$a<$colCount;$a++)	{
-						$columnWidths[$a] = $defaultColumnWidth;
-					}
-				}
-			}
-		}
+		$columnWidths = $this->getImgColumnWidths($conf, $colCount, $netW);
+		
 		$image_compression = intval($this->cObj->stdWrap($conf['image_compression'],$conf['image_compression.']));
 		$image_effects = intval($this->cObj->stdWrap($conf['image_effects'],$conf['image_effects.']));
 		$image_frames = intval($this->cObj->stdWrap($conf['image_frames.']['key'],$conf['image_frames.']['key.']));
@@ -555,12 +615,14 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			$gifCreator = t3lib_div::makeInstance('tslib_gifbuilder');
 			$gifCreator->init();
 			$relations_cols = Array();
+			$imgWidths = array(); // contains the individual width of all images after scaling to $equalHeight
 			for ($a=0; $a<$imgCount; $a++)	{
 				$imgKey = $a+$imgStart;
 				$imgInfo = $gifCreator->getImageDimensions($imgPath.$imgs[$imgKey]);
 				$rel = $imgInfo[1] / $equalHeight;	// relationship between the original height and the wished height
 				if ($rel)	{	// if relations is zero, then the addition of this value is omitted as the image is not expected to display because of some error.
-					$relations_cols[floor($a/$colCount)] += $imgInfo[0]/$rel;	// counts the total width of the row with the new height taken into consideration.
+					$imgWidths[$a] = $imgInfo[0] / $rel;
+					$relations_cols[floor($a/$colCount)] += $imgWidths[$a];	// counts the total width of the row with the new height taken into consideration.
 				}
 			}
 		}
@@ -573,6 +635,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 		$imageRowsFinalWidths = Array();	// contains the width of every image row
 		$imgsTag = array();		// array index of $imgsTag will be the same as in $imgs, but $imgsTag only contains the images that are actually shown
 		$origImages = array();
+		$rowIdx = 0;
 		for ($a=0; $a<$imgCount; $a++)	{
 			$imgKey = $a+$imgStart;
 			$totalImagePath = $imgPath.$imgs[$imgKey];
@@ -586,18 +649,33 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 			$imgConf = $conf[$imgObjNum.'.'];
 
 			if ($equalHeight)	{
-				$scale = 1;
-				$totalMaxW = $defaultColumnWidth*$colCount;
-				$rowTotalMaxW = $relations_cols[floor($a/$colCount)];
-				if ($rowTotalMaxW > $totalMaxW)	{
-					$scale = $rowTotalMaxW / $totalMaxW;
+				
+				if ($a % $colCount == 0) {
+						// a new row startsS
+					$accumWidth = 0; // reset accumulated net width
+					$accumDesiredWidth = 0; // reset accumulated desired width
+					$rowTotalMaxW = $relations_cols[$rowIdx];
+					if ($rowTotalMaxW > $netW)	{
+						$scale = $rowTotalMaxW / $netW;
+					} else {
+						$scale = 1;
+					}
+					$desiredHeight = $equalHeight / $scale;
+					$rowIdx++;
 				}
-
-					// transfer info to the imageObject. Please note, that
-				$imgConf['file.']['height'] = round($equalHeight/$scale);
+				
+				$availableWidth= $netW - $accumWidth; // this much width is available for the remaining images in this row (int)
+				$desiredWidth= $imgWidths[$a] / $scale; // theoretical width of resized image. (float)
+				$accumDesiredWidth += $desiredWidth; // add this width. $accumDesiredWidth becomes the desired horizontal position 
+					// calculate width by comparing actual and desired horizontal position.
+					// this evenly distributes rounding errors across all images in this row. 
+				$suggestedWidth = round($accumDesiredWidth - $accumWidth);
+				$finalImgWidth = (int) min($availableWidth, $suggestedWidth); // finalImgWidth may not exceed $availableWidth
+				$accumWidth += $finalImgWidth;
+				$imgConf['file.']['width'] = $finalImgWidth;
+				$imgConf['file.']['height'] = round($desiredHeight);
 
 					// other stuff will be calculated accordingly:
-				unset($imgConf['file.']['width']);
 				unset($imgConf['file.']['maxW']);
 				unset($imgConf['file.']['maxH']);
 				unset($imgConf['file.']['minW']);
@@ -694,6 +772,9 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 		}
 
 			// Edit icons:
+		if (!is_array($conf['editIcons.'])) {
+			$conf['editIcons.'] = array();
+		}
 		$editIconsHTML = $conf['editIcons']&&$GLOBALS['TSFE']->beUserLogin ? $this->cObj->editIcons('',$conf['editIcons'],$conf['editIcons.']) : '';
 
 			// If noRows, we need multiple imagecolumn wraps
@@ -810,7 +891,7 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 		}
 		$borderClass = '';
 		if ($border)	{
-			$borderClass = 'csc-textpic-border';
+			$borderClass = $conf['borderClass'] ? $conf['borderClass'] : 'csc-textpic-border';
 		}
 
 			// Multiple classes with all properties, to be styled in CSS
@@ -873,6 +954,40 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 	 *
 	 ************************************/
 
+	/**
+	 * Returns a link text string which replaces underscores in filename with
+	 * blanks.
+	 *
+	 * Has the possibility to cut off FileType.
+
+	 * @param array $links
+	 *        array with [0] linked file icon, [1] text link
+	 * @param string $fileName
+	 *        the name of the file to be linked (without path)
+	 * @param boolean $useSpaces
+	 *        whether underscores in the file name should be replaced with spaces
+	 * @param boolean $cutFileExtension
+	 *        whether the file extension should be removed
+	 *
+	 * @return array modified array with new link text
+	 */
+	protected function beautifyFileLink(
+		array $links, $fileName, $useSpaces = FALSE, $cutFileExtension = FALSE
+	) {
+		$linkText = $fileName;
+		if ($useSpaces) {
+			$linkText = str_replace('_', ' ', $linkText);
+		}
+		if ($cutFileExtension) {
+			$pos = strrpos($linkText, '.');
+			$linkText = substr($linkText, 0, $pos);
+		}
+		$links[1] = str_replace(
+			'>' . $fileName . '<', '>' . $linkText . '<', $links[1]
+		);
+		return $links;
+	}
+
 	/**
 	 * Returns table attributes for uploads / tables.
 	 *
@@ -925,8 +1040,8 @@ class tx_cssstyledcontent_pi1 extends tslib_pibase {
 
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/css_styled_content/pi1/class.tx_cssstyledcontent_pi1.php'])	{
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/css_styled_content/pi1/class.tx_cssstyledcontent_pi1.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/css_styled_content/pi1/class.tx_cssstyledcontent_pi1.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/css_styled_content/pi1/class.tx_cssstyledcontent_pi1.php']);
 }
 
 ?>
\ No newline at end of file
