@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Module: Indexing Engine Overview
  *
- * @author	Kasper Skrhj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 /**
  * [CLASS/FUNCTION INDEX of SCRIPT]
@@ -76,7 +76,7 @@ require_once(t3lib_extMgm::extPath('indexed_search') . 'class.indexer.php');
 /**
  * Backend module providing boring statistics of the index-tables.
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage tx_indexedsearch
  */
@@ -234,8 +234,7 @@ class SC_mod_tools_isearch_index {
 	function getRecordsNumbers()	{
 		$tables=explode(",","index_phash,index_words,index_rel,index_grlist,index_section,index_fulltext");
 		$recList=array();
-		reset($tables);
-		while(list(,$t)=each($tables))	{
+		foreach ($tables as $t) {
 			$recList[] = array(
 				$this->tableHead($t),
 				$GLOBALS['TYPO3_DB']->exec_SELECTcountRows('*', $t)
@@ -435,9 +434,8 @@ class SC_mod_tools_isearch_index {
 	 * @return	[type]		...
 	 */
 	function formatFeGroup($fegroup_recs)	{
-		reset($fegroup_recs);
 		$str = array();
-		while(list(,$row)=each($fegroup_recs))	{
+		foreach ($fegroup_recs as $row) {
 			$str[] = $row["gr_list"]=="0,-1" ? "NL" : $row["gr_list"];
 		}
 		arsort($str);
@@ -451,12 +449,11 @@ class SC_mod_tools_isearch_index {
 	 * @return	[type]		...
 	 */
 	function formatCHash($arr)	{
-		reset($arr);
-		$list=array();
-		while(list($k,$v)=each($arr))	{
+		$list = array();
+		foreach ($arr as $k => $v) {
 			$list[] = htmlspecialchars($k) . '=' . htmlspecialchars($v);
 		}
-		return implode("<BR>",$list);
+		return implode('<br />', $list);
 	}
 
 	/**
