@@ -3,7 +3,7 @@
 ########################################################################
 # Extension Manager/Repository config file for ext "tstemplate_objbrowser".
 #
-# Auto generated 21-10-2009 11:27
+# Auto generated 26-01-2011 20:08
 #
 # Manual updates:
 # Only the data in the array - everything else is removed by next
@@ -33,13 +33,13 @@ $EM_CONF[$_EXTKEY] = array(
 	'author_company' => 'Curby Soft Multimedia',
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
-	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:6:{s:9:"ChangeLog";s:4:"63a4";s:33:"class.tx_tstemplateobjbrowser.php";s:4:"c7f1";s:12:"ext_icon.gif";s:4:"4226";s:14:"ext_tables.php";s:4:"a29f";s:13:"locallang.xml";s:4:"d28f";s:12:"doc/TODO.txt";s:4:"6bb0";}',
+	'version' => '1.0.0',
+	'_md5_values_when_last_written' => 'a:6:{s:9:"ChangeLog";s:4:"63a4";s:33:"class.tx_tstemplateobjbrowser.php";s:4:"e8e6";s:12:"ext_icon.gif";s:4:"c2e1";s:14:"ext_tables.php";s:4:"a29f";s:13:"locallang.xml";s:4:"d28f";s:12:"doc/TODO.txt";s:4:"6bb0";}',
 	'constraints' => array(
 		'depends' => array(
 			'tstemplate' => '',
 			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.3.0-4.3.99',
+			'typo3' => '4.4.0-0.0.0',
 		),
 		'conflicts' => array(
 		),
