@@ -3,7 +3,7 @@
 ########################################################################
 # Extension Manager/Repository config file for ext "viewpage".
 #
-# Auto generated 25-11-2009 22:14
+# Auto generated 26-01-2011 20:08
 #
 # Manual updates:
 # Only the data in the array - everything else is removed by next
@@ -33,13 +33,13 @@ $EM_CONF[$_EXTKEY] = array(
 	'author_company' => 'Curby Soft Multimedia',
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
-	'version' => '0.1.1',
-	'_md5_values_when_last_written' => 'a:10:{s:12:"ext_icon.gif";s:4:"eb74";s:14:"ext_tables.php";s:4:"a104";s:14:"view/clear.gif";s:4:"cc11";s:13:"view/conf.php";s:4:"33e4";s:15:"view/dummy.html";s:4:"e302";s:17:"view/frameset.php";s:4:"a100";s:14:"view/index.php";s:4:"d448";s:15:"view/layout.gif";s:4:"9730";s:22:"view/locallang_mod.xml";s:4:"ebf1";s:13:"view/view.gif";s:4:"e65c";}',
+	'version' => '1.0.0',
+	'_md5_values_when_last_written' => 'a:10:{s:12:"ext_icon.gif";s:4:"9b98";s:14:"ext_tables.php";s:4:"a104";s:14:"view/clear.gif";s:4:"cc11";s:13:"view/conf.php";s:4:"33e4";s:15:"view/dummy.html";s:4:"e302";s:17:"view/frameset.php";s:4:"a100";s:14:"view/index.php";s:4:"3ea6";s:15:"view/layout.gif";s:4:"edde";s:22:"view/locallang_mod.xml";s:4:"ebf1";s:13:"view/view.gif";s:4:"1898";}',
 	'constraints' => array(
 		'depends' => array(
 			'cms' => '',
 			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.3.0-4.3.99',
+			'typo3' => '4.4.0-0.0.0',
 		),
 		'conflicts' => array(
 		),
