@@ -83,6 +83,7 @@ class tx_Workspaces_ExtDirect_Server extends tx_Workspaces_ExtDirect_AbstractHan
 
 		$t3lib_diff = t3lib_div::makeInstance('t3lib_diff');
 		$stagesService = t3lib_div::makeInstance('Tx_Workspaces_Service_Stages');
+		$parseObj = t3lib_div::makeInstance('t3lib_parsehtml_proc');
 
 		$liveRecord = t3lib_BEfunc::getRecord($parameter->table, $parameter->t3ver_oid);
 		$versionRecord = t3lib_BEfunc::getRecord($parameter->table, $parameter->uid);
@@ -139,7 +140,7 @@ class tx_Workspaces_ExtDirect_Server extends tx_Workspaces_ExtDirect_AbstractHan
 						$liveReturnArray[] = array(
 							'field' => $fieldName,
 							'label' => $fieldTitle,
-							'content' => $liveRecord[$fieldName]
+							'content' => $parseObj->TS_images_rte($liveRecord[$fieldName])
 						);
 					}
 				}
